[zorg] r181516 - Increase timeout for LTO builder

David Dean david_dean at apple.com
Thu May 9 09:20:02 PDT 2013


Author: ddean
Date: Thu May  9 11:20:01 2013
New Revision: 181516

URL: http://llvm.org/viewvc/llvm-project?rev=181516&view=rev
Log:
Increase timeout for LTO builder

Modified:
    zorg/trunk/zorg/buildbot/builders/ClangBuilder.py

Modified: zorg/trunk/zorg/buildbot/builders/ClangBuilder.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/buildbot/builders/ClangBuilder.py?rev=181516&r1=181515&r2=181516&view=diff
==============================================================================
--- zorg/trunk/zorg/buildbot/builders/ClangBuilder.py (original)
+++ zorg/trunk/zorg/buildbot/builders/ClangBuilder.py Thu May  9 11:20:01 2013
@@ -800,7 +800,7 @@ def phasedClang(config_options, is_boots
     timeout = 20*60 # Normal timeout is 20 minutes.
     if use_lto:
         make_command.append(WithProperties('DYLD_LIBRARY_PATH=%(liblto_path)s'))
-        timeout = 120*60 # LTO timeout is 120 minutes.
+        timeout = 180*60 # LTO timeout is 180 minutes.
     
     f.addStep(buildbot.steps.shell.ShellCommand(
               name='make', command=make_command,





More information about the llvm-commits mailing list